@@ -18,6 +18,19 @@
 `is.ktensor` <- function(x){inherits(x,"ktensor")}
 `is.kform` <- function(x){inherits(x,"kform")}
 
+`spray` <- function(M,x,addrepeats=FALSE){spray::spray(M,x,addrepeats=addrepeats)}
+`as.spray` <- function(arg1, arg2, addrepeats=FALSE, offbyone=FALSE){
+    spray::as.spray(arg1, arg2, addrepeats=FALSE, offbyone=FALSE)
+}
+`is.zero` <- function(x){spray::is.zero(x)}
+`is.empty` <- function(x){spray::is.empty(x)}
+`nterms` <- function(x){spray::nterms(x)}
+`coeffs` <- function(x){spray::coeffs(x)}
+
+`coeffs<-` <- function(S,value){UseMethod("coeffs<-")}
+`coeffs<-.spray` <- function(S,value){spray::`coeffs<-`(S,value)}
+#`zero` <- function(n){spray::spray(matrix(0,0,n),numeric(0))}
+
 `as.function.ktensor` <- function(x, ...){
     stopifnot(is.ktensor(x))
     if(is.zero(x)){return(function(E){0})}
@@ -446,6 +459,8 @@ setGeneric("lose",function(x){standardGeneric("lose")})
     (-1)^n*sapply(seq_len(n),function(i){(-1)^i*det(M[-i,])})
 }
 
+`vcp3` <- function(u,v){hodge(as.1form(u) ^ as.1form(v))}
+
 `kinner` <- function(o1,o2,M){
     stopifnot(arity(o1) == arity(o2))
     k <- arity(o1)
